@@ -1,15 +1,15 @@
 package Finance::Bank::ID::Mandiri;
 
 use 5.010;
-use Log::Any;
 
 use Moo;
 use DateTime;
 
-use HTTP::Headers::Patch::DontUseStorable;
+use HTTP::Headers;
+use HTTP::Headers::Patch::DontUseStorable -load_target=>0;
 extends 'Finance::Bank::ID::Base';
 
-our $VERSION = '0.24'; # VERSION
+our $VERSION = '0.25'; # VERSION
 
 has _variant => (is => 'rw');
 has _re_tx   => (is => 'rw');
@@ -164,17 +164,30 @@ sub check_balance {
 sub get_statement {
     my ($self, %args) = @_;
     my $s = $self->site;
-    my $max_days = 31;
 
     $self->login;
 
+    $self->logger->debug('Getting statement ...');
     my $mech = $self->mech;
     $self->_req(get => ["$s/retail/TrxHistoryInq.do?action=form"]);
 
     my $today = DateTime->today;
     my $end_date = $args{end_date} || $today;
-    my $start_date = $args{start_date} ||
-        $end_date->clone->subtract(days=>(($args{days} || $max_days)-1));
+    my $start_date = $args{start_date};
+    if (!$start_date) {
+        if (defined $args{days}) {
+            $start_date = $end_date->clone->subtract(days=>($args{days}-1));
+            $self->logger->debugf(
+                'Setting start_date to %04d-%02d-%02d (end_date - %d days)',
+                $start_date->year, $start_date->month, $start_date->day,
+                $args{days});
+        } else {
+            $start_date = $end_date->clone->subtract(months=>1);
+            $self->logger->debugf(
+                'Setting start_date to %04d-%02d-%02d (end_date - 1mo)',
+                $start_date->year, $start_date->month, $start_date->day);
+        }
+    }
 
     $mech->set_fields(
         fromAccountID => $self->_get_an_account_id($args{account}, 0),
@@ -194,8 +207,10 @@ sub get_statement {
     $self->_req(submit => [],
                 sub {
                     my ($mech) = @_;
-                    $mech->content =~ /saldo/i or return "failed getting statement";
-                    "";
+                    $mech->content =~ /saldo/i and return "";
+                    $mech->content =~ m!<font class="alert">(.+)</font>!
+                        and return $1;
+                    return "failed getting statement";
                 });
 
     my $resp = $self->parse_statement($self->mech->content);
@@ -590,7 +605,7 @@ Finance::Bank::ID::Mandiri - Check your Bank Mandiri accounts from Perl
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -618,7 +633,7 @@ version 0.24
 
         my $stmt = $ibank->get_statement(
             account    => ..., # opt, default account used if not undef
-            days       => 31,  # opt
+            days       => 30,  # opt
             start_date => DateTime->new(year=>2009, month=>10, day=>6),
                                # opt, takes precedence over 'days'
             end_date   => DateTime->today, # opt, takes precedence over 'days'
@@ -786,12 +801,15 @@ already selected account.
 
 =item * days
 
-Optional. Number of days between 1 and 31. If days is 1, then start date and end
-date will be the same. Default is 31.
+Optional. Number of days. If days is 1, then start date and end date will be the
+same.
 
 =item * start_date
 
-Optional. Default is end_date - days.
+Optional. Default is C<end_date> - 1 month, which seems to be the current limit
+set by the bank (for example, if C<end_date> is 2013-03-08, then C<start_date>
+will be set to 2013-02-08). If not set and C<days> is set, will be set to
+C<end_date> - C<days>.
 
 =item * end_date
 
@@ -856,7 +874,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
